LocalAuthWatchos class base
watchOS implementation of LocalAuthPlatform.
- Inheritance
-
- Object
- PlatformInterface
- LocalAuthPlatform
- LocalAuthWatchos
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
{required String localizedReason, required Iterable< AuthMessages> authMessages, AuthenticationOptions options = const AuthenticationOptions()}) → Future<bool> -
Prompts for device-owner authentication.
override
-
deviceSupportsBiometrics(
) → Future< bool> -
Returns true if the device is capable of checking biometrics.
override
-
getEnrolledBiometrics(
) → Future< List< BiometricType> > -
Returns a list of enrolled biometrics.
override
-
isDeviceSupported(
) → Future< bool> -
Returns true if device is capable of checking biometrics or is able to
fail over to device credentials.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stopAuthentication(
) → Future< bool> -
Cancels any authentication currently in progress.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- backendOverride ↔ LocalAuthWatchosBackend?
-
Test hook: set before first use to replace the native backend with a fake.
getter/setter pair
- timeout ↔ Duration
-
How long to wait for the system's authentication UI before giving up.
getter/setter pair
Static Methods
-
registerWith(
) → void -
Registers this implementation as the default
local_authplatform implementation on watchOS.